@@ -8,7 +8,7 @@
 #'@importFrom utils read.table
 #'@importFrom progress progress_bar
 #'@examples \dontrun{
-#' lagosne_ingest("1.087.1",
+#' lagos_ingest("1.087.1",
 #'  limno_folder = "~/Downloads/LAGOS-NE-LIMNO-EXPORT",
 #'  geo_folder   = "~/Downloads/LAGOS-NE-GEO-EXPORT",
 #'  locus_folder = "~/Downloads/LAGOS-NE-LOCUS-EXPORT")
@@ -23,10 +23,10 @@ lagos_ingest <- function(version, limno_folder = NA, geo_folder = NA,
   folder_version <- gsub("\\.", "", version)
 
   # Set-up paths ####
-  limno_prefix <- paste0(limno_folder, "/", "LAGOSNE_")
+  limno_prefix <- paste0(limno_folder, "/")
   limno_path   <- function(fname){
                     paste0(limno_prefix,
-                    fname, folder_version, ".csv")
+                           fname, folder_version, ".csv")
                   }
 
   geo_prefix   <- paste0(geo_folder, "/", "LAGOSNE_")
@@ -41,24 +41,24 @@ lagos_ingest <- function(version, limno_folder = NA, geo_folder = NA,
                     fname, "101.csv")
                   }
 
-  # Importing Lagos limno data ####
+  # Importing LAGOS limno data ####
   pb$tick(tokens = list(type = "limno data"))
-  epi_nutr             <- load_lagos_txt(limno_path("epinutr"),
+
+  epi_nutr             <- load_lagos_txt(limno_path("epi_waterquality"),
                               sep = ",")
   epi_nutr$sampledate  <- as.Date(strptime(epi_nutr$sampledate,
                                            format = "%m/%d/%Y"))
 
-  lakes_limno          <- load_lagos_txt(limno_path("lakeslimno"),
-                                       sep = ",")
-  secchi               <- load_lagos_txt(limno_path("secchi"),
-                                         sep = ",")
+  lakes_limno          <- read.csv(limno_path("lakeslimno"),
+                                   stringsAsFactors = FALSE)
+  lakes_limno$legacyid <-
+    suppressWarnings(sapply(lakes_limno$legacyid, format_nonscientific))
+
   lagos_source_program <- load_lagos_txt(limno_path("sourceprogram"),
                                          sep = ",")
 
   limno <- list(epi_nutr = epi_nutr,
                 lakes_limno = lakes_limno,
-                secchi = secchi,
-                # lagos.censor.epi = lagos.censor.epi,
                 lagos_source_program = lagos_source_program)
 
   # Importing Lagos Geo data ####
