@@ -13,6 +13,17 @@ test_that("lake_info works", {
 
 })
 
+test_that("lake_info works with the full export", {
+  skip_on_cran()
+  skip_on_travis()
+  skip_on_appveyor()
+
+  llids <- c("6992", "7026")
+  expect_equal(nrow(
+    lake_info(llids)
+    ), 2)
+})
+
 test_that("lake_info works with corner cases", {
   skip_on_cran()
   skip_on_travis()
